
  <table class="table">
    <thead>
      <tr>
        <th>Page</th>
        <th>Line</th>
        <th>Text</th>
      </tr>
    </thead>
    <tbody>
      {% for r in results|sort %}
      <tr>
        <td class="col-md-1">{{ r[0] }}</td>
        <td class="col-md-1">{{ r[1] }}</td>
        <td>{{ r[2] }}</td>
      </tr>
      {% endfor %}
    </tbody>
  </table>

  </div>
